"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IdentifyEventSchema = exports.TrackEventSchema = exports.TrackAIFeedbackSchema = exports.TrackAIQuerySchema = exports.TrackAIConversationSchema = void 0;
const zod_1 = require("zod");
// Schema for tracking AI conversation events
exports.TrackAIConversationSchema = zod_1.z
    .object({
    user_id: zod_1.z.string().min(1, "User ID is required"),
    conversation_id: zod_1.z.string().min(1, "Conversation ID is required"),
    event_type: zod_1.z.enum([
        "conversation_started",
        "conversation_ended",
        "message_sent",
        "response_received",
    ]),
    properties: zod_1.z
        .object({
        model_name: zod_1.z.string().optional(),
        input_tokens: zod_1.z.number().min(0).optional(),
        output_tokens: zod_1.z.number().min(0).optional(),
        response_time_ms: zod_1.z.number().min(0).optional(),
        conversation_context: zod_1.z.record(zod_1.z.any()).optional(),
        success: zod_1.z.boolean().optional(),
        error_details: zod_1.z.string().optional(),
        message_content: zod_1.z.string().optional(),
        response_content: zod_1.z.string().optional(),
    })
        .optional()
        .default({}),
    anonymous_id: zod_1.z.string().optional(),
    timestamp: zod_1.z.string().optional(),
})
    .strict();
// Schema for tracking AI queries and responses
exports.TrackAIQuerySchema = zod_1.z
    .object({
    user_id: zod_1.z.string().min(1, "User ID is required"),
    conversation_id: zod_1.z.string().min(1, "Conversation ID is required"),
    query: zod_1.z.string().min(1, "Query is required"),
    response: zod_1.z.string().optional(),
    model_used: zod_1.z.string().min(1, "Model name is required"),
    response_time_ms: zod_1.z.number().min(0).optional(),
    success: zod_1.z.boolean(),
    error_details: zod_1.z.string().optional(),
    anonymous_id: zod_1.z.string().optional(),
    timestamp: zod_1.z.string().optional(),
    additional_properties: zod_1.z.record(zod_1.z.any()).optional(),
})
    .strict();
// Schema for tracking AI feedback events
exports.TrackAIFeedbackSchema = zod_1.z
    .object({
    user_id: zod_1.z.string().min(1, "User ID is required"),
    conversation_id: zod_1.z.string().min(1, "Conversation ID is required"),
    message_id: zod_1.z.string().min(1, "Message ID is required"),
    feedback_type: zod_1.z.enum(["thumbs_up", "thumbs_down", "rating"]),
    feedback_value: zod_1.z.number().min(1).max(5).optional(),
    feedback_text: zod_1.z.string().optional(),
    anonymous_id: zod_1.z.string().optional(),
    timestamp: zod_1.z.string().optional(),
    additional_properties: zod_1.z.record(zod_1.z.any()).optional(),
})
    .strict();
// Schema for general event tracking
exports.TrackEventSchema = zod_1.z
    .object({
    user_id: zod_1.z.string().optional(),
    anonymous_id: zod_1.z.string().optional(),
    event: zod_1.z.string().min(1, "Event name is required"),
    properties: zod_1.z.record(zod_1.z.any()).optional(),
    timestamp: zod_1.z.string().optional(),
    context: zod_1.z.record(zod_1.z.any()).optional(),
    integrations: zod_1.z.record(zod_1.z.any()).optional(),
})
    .refine((data) => data.user_id || data.anonymous_id, {
    message: "Either user_id or anonymous_id must be provided",
});
// Schema for identify events
exports.IdentifyEventSchema = zod_1.z
    .object({
    user_id: zod_1.z.string().min(1, "User ID is required"),
    traits: zod_1.z.record(zod_1.z.any()).optional(),
    anonymous_id: zod_1.z.string().optional(),
    timestamp: zod_1.z.string().optional(),
    context: zod_1.z.record(zod_1.z.any()).optional(),
    integrations: zod_1.z.record(zod_1.z.any()).optional(),
})
    .strict();
//# sourceMappingURL=tracking-schemas.js.map