"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SegmentMcp = void 0;
const index_js_1 = require("@modelcontextprotocol/sdk/server/index.js");
const types_js_1 = require("@modelcontextprotocol/sdk/types.js");
const logger_js_1 = require("../utils/logger.js");
const profile_client_js_1 = require("../clients/profile-client.js");
const tracking_client_js_1 = require("../clients/tracking-client.js");
const profile_tools_js_1 = require("../tools/profile-tools.js");
const tracking_tools_js_1 = require("../tools/tracking-tools.js");
class SegmentMcp {
    constructor(options) {
        this.config = options.config;
        this.serverName = options.name || "segment-mcp-server";
        this.serverVersion = options.version || "1.0.0";
        this.logger = (0, logger_js_1.createLogger)(this.config.logLevel);
        this.logger.info("Initializing Segment MCP server...");
        this.logger.info("Creating logger with level:", this.config.logLevel);
        // Initialize clients
        this.logger.info("Initializing Segment clients...");
        this.profileClient = new profile_client_js_1.SegmentProfileClient(this.config);
        this.trackingClient = new tracking_client_js_1.SegmentTrackingClient(this.config);
        this.logger.info("Segment clients initialized successfully");
        // Initialize MCP server
        this.logger.info("Initializing MCP server...");
        this.server = new index_js_1.Server({
            name: this.serverName,
            version: this.serverVersion,
        }, {
            capabilities: {
                tools: {},
            },
        });
        this.logger.info("MCP server instance created");
        this.setupHandlers();
        this.logger.info("Segment MCP Server initialized successfully");
    }
    setupHandlers() {
        this.logger.info("Setting up request handlers...");
        // Handle initialization
        this.logger.info("Setting up initialize handler...");
        this.server.setRequestHandler(types_js_1.InitializeRequestSchema, (request) => __awaiter(this, void 0, void 0, function* () {
            this.logger.info("Received initialize request", {
                protocolVersion: request.params.protocolVersion,
                clientInfo: request.params.clientInfo,
            });
            try {
                this.logger.info("Preparing initialize response");
                const response = {
                    protocolVersion: "2024-11-05",
                    capabilities: {
                        tools: {},
                        resources: {},
                        prompts: {},
                    },
                    serverInfo: {
                        name: this.serverName,
                        version: this.serverVersion,
                    },
                };
                this.logger.info("Sending initialize response", { response });
                return response;
            }
            catch (error) {
                this.logger.error("Error in initialize handler", {
                    error: error.message,
                    stack: error.stack,
                });
                throw error;
            }
        }));
        this.logger.info("Initialize handler set up successfully");
        // Handle tool listing
        this.server.setRequestHandler(types_js_1.ListToolsRequestSchema, () => __awaiter(this, void 0, void 0, function* () {
            const profileTools = (0, profile_tools_js_1.createProfileTools)(this.profileClient);
            const trackingTools = (0, tracking_tools_js_1.createTrackingTools)();
            return {
                tools: [...profileTools, ...trackingTools],
            };
        }));
        // Handle tool execution
        this.server.setRequestHandler(types_js_1.CallToolRequestSchema, (request) => __awaiter(this, void 0, void 0, function* () {
            const { name, arguments: params } = request.params;
            this.logger.info(`Executing tool: ${name}`, { params });
            try {
                let result;
                // Route to appropriate tool handler
                if (this.isProfileTool(name)) {
                    result = yield (0, profile_tools_js_1.executeProfileTool)(name, params || {}, this.profileClient);
                }
                else if (this.isTrackingTool(name)) {
                    result = yield (0, tracking_tools_js_1.executeTrackingTool)(name, params || {}, this.trackingClient);
                }
                else {
                    throw new Error(`Unknown tool: ${name}`);
                }
                this.logger.info(`Tool execution completed: ${name}`, {
                    success: result.success,
                    hasError: !!result.error,
                });
                return {
                    content: [
                        {
                            type: "text",
                            text: JSON.stringify(result, null, 2),
                        },
                    ],
                };
            }
            catch (error) {
                this.logger.error(`Tool execution failed: ${name}`, {
                    error: error.message,
                    stack: error.stack,
                });
                return {
                    content: [
                        {
                            type: "text",
                            text: JSON.stringify({
                                success: false,
                                error: error.message,
                                tool: name,
                            }, null, 2),
                        },
                    ],
                    isError: true,
                };
            }
        }));
    }
    isProfileTool(toolName) {
        const profileTools = [
            "get_profile_traits",
            "get_profile_events",
            "get_profile_past_chat",
        ];
        return profileTools.includes(toolName);
    }
    isTrackingTool(toolName) {
        const trackingTools = [
            "track_ai_conversation",
            "track_ai_query",
            "track_ai_feedback",
            "track_custom_event",
            "identify_user",
        ];
        return trackingTools.includes(toolName);
    }
    /**
     * Start the MCP server with the provided transport
     */
    start(transport) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.info("Starting MCP server with provided transport...");
            try {
                yield this.server.connect(transport);
                this.logger.info("Segment MCP Server connected and ready to handle requests");
            }
            catch (error) {
                this.logger.error("Failed to connect server to transport", {
                    error: error.message,
                    stack: error.stack,
                });
                throw error;
            }
        });
    }
    /**
     * Get the underlying MCP server instance
     */
    getServer() {
        return this.server;
    }
    /**
     * Get the logger instance
     */
    getLogger() {
        return this.logger;
    }
    /**
     * Get the configuration
     */
    getConfig() {
        return this.config;
    }
}
exports.SegmentMcp = SegmentMcp;
//# sourceMappingURL=segment-mcp.js.map