"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProfileTools = createProfileTools;
exports.executeProfileTool = executeProfileTool;
const profile_schemas_js_1 = require("../schemas/profile-schemas.js");
function createProfileTools(profileClient) {
    return [
        {
            name: "get_profile_traits",
            description: "Get user traits from Segment Profile API using external ID (e.g., email:user@example.com)",
            inputSchema: {
                type: "object",
                properties: {
                    external_id: {
                        type: "string",
                        description: "The external identifier in format type:value (e.g., email:user@example.com)",
                    },
                    space_id: {
                        type: "string",
                        description: "Optional Segment space ID (uses default if not provided)",
                    },
                },
                required: ["external_id"],
            },
        },
        {
            name: "get_profile_events",
            description: "Get user events from Segment Profile API using external ID (e.g., email:user@example.com)",
            inputSchema: {
                type: "object",
                properties: {
                    external_id: {
                        type: "string",
                        description: "The external identifier in format type:value (e.g., email:user@example.com)",
                    },
                    limit: {
                        type: "number",
                        description: "Maximum number of events to return (1-200)",
                        minimum: 1,
                        maximum: 200,
                    },
                    cursor: {
                        type: "string",
                        description: "Cursor for pagination to get next page of events",
                    },
                    space_id: {
                        type: "string",
                        description: "Optional Segment space ID (uses default if not provided)",
                    },
                },
                required: ["external_id"],
            },
        },
        {
            name: "get_profile_past_chat",
            description: "Get user events related to past chat with AI from Segment Profile API using external ID (e.g., email:user@example.com)",
            inputSchema: {
                type: "object",
                properties: {
                    external_id: {
                        type: "string",
                        description: "The external identifier in format type:value (e.g., email:user@example.com)",
                    },
                    limit: {
                        type: "number",
                        description: "Maximum number of events to return (1-200)",
                        minimum: 1,
                        maximum: 200,
                    },
                    cursor: {
                        type: "string",
                        description: "Cursor for pagination to get next page of events",
                    },
                    space_id: {
                        type: "string",
                        description: "Optional Segment space ID (uses default if not provided)",
                    },
                },
                required: ["external_id"],
            },
        },
    ];
}
function executeProfileTool(toolName, params, profileClient) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            switch (toolName) {
                case "get_profile_traits": {
                    const validatedParams = profile_schemas_js_1.GetProfileTraitsSchema.parse(params);
                    const traitsResponse = yield profileClient.getProfileTraits(validatedParams.external_id, validatedParams.space_id);
                    return {
                        success: true,
                        external_id: validatedParams.external_id,
                        traits: traitsResponse.traits,
                        cursor: traitsResponse.cursor,
                    };
                }
                case "get_profile_events": {
                    const validatedParams = profile_schemas_js_1.GetProfileEventsSchema.parse(params);
                    const eventsResponse = yield profileClient.getProfileEvents(validatedParams.external_id, {
                        limit: validatedParams.limit,
                        cursor: validatedParams.cursor,
                        spaceId: validatedParams.space_id,
                        exclude: "AI Conversation Started,AI Message Sent,AI Response Received,AI Query Executed,AI Feedback Given",
                    });
                    if (!eventsResponse.data || !Array.isArray(eventsResponse.data)) {
                        throw new Error("No events found for the given profile.");
                    }
                    return {
                        success: true,
                        external_id: validatedParams.external_id,
                        events: eventsResponse.data,
                        cursor: eventsResponse.cursor,
                        total_events: eventsResponse.data.length,
                    };
                }
                case "get_profile_past_chat": {
                    const validatedParams = profile_schemas_js_1.GetProfilePastChatSchema.parse(params);
                    const eventsResponse = yield profileClient.getProfileEvents(validatedParams.external_id, {
                        limit: validatedParams.limit,
                        cursor: validatedParams.cursor,
                        spaceId: validatedParams.space_id,
                        include: "AI Conversation Started,AI Message Sent,AI Response Received,AI Query Executed,AI Feedback Given",
                    });
                    if (!eventsResponse.data || !Array.isArray(eventsResponse.data)) {
                        throw new Error("No events found for the given profile.");
                    }
                    return {
                        success: true,
                        external_id: validatedParams.external_id,
                        events: eventsResponse.data,
                        cursor: eventsResponse.cursor,
                        total_events: eventsResponse.data.length,
                    };
                }
                default:
                    throw new Error(`Unknown profile tool: ${toolName}`);
            }
        }
        catch (error) {
            return {
                success: false,
                error: error.message,
                tool: toolName,
            };
        }
    });
}
//# sourceMappingURL=profile-tools.js.map