"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTrackingTools = createTrackingTools;
exports.executeTrackingTool = executeTrackingTool;
const tracking_schemas_js_1 = require("../schemas/tracking-schemas.js");
function createTrackingTools() {
    return [
        {
            name: "track_ai_conversation",
            description: "Track AI copilot conversation events according to Segment AI spec",
            inputSchema: {
                type: "object",
                properties: {
                    user_id: {
                        type: "string",
                        description: "The unique identifier for the user",
                    },
                    conversation_id: {
                        type: "string",
                        description: "Unique identifier for the conversation session",
                    },
                    event_type: {
                        type: "string",
                        enum: [
                            "conversation_started",
                            "conversation_ended",
                            "message_sent",
                            "response_received",
                        ],
                        description: "Type of conversation event",
                    },
                    properties: {
                        type: "object",
                        description: "Additional event properties",
                        properties: {
                            model_name: { type: "string" },
                            input_tokens: { type: "number" },
                            output_tokens: { type: "number" },
                            response_time_ms: { type: "number" },
                            conversation_context: { type: "object" },
                            success: { type: "boolean" },
                            error_details: { type: "string" },
                            message_content: { type: "string" },
                            response_content: { type: "string" },
                        },
                    },
                    anonymous_id: {
                        type: "string",
                        description: "Anonymous identifier if user_id is not available",
                    },
                    timestamp: {
                        type: "string",
                        description: "ISO 8601 timestamp (defaults to current time)",
                    },
                },
                required: ["user_id", "conversation_id", "event_type"],
            },
        },
        {
            name: "track_ai_query",
            description: "Track AI query and response events with detailed metadata",
            inputSchema: {
                type: "object",
                properties: {
                    user_id: {
                        type: "string",
                        description: "The unique identifier for the user",
                    },
                    conversation_id: {
                        type: "string",
                        description: "Unique identifier for the conversation session",
                    },
                    query: {
                        type: "string",
                        description: "The user's query or prompt",
                    },
                    response: {
                        type: "string",
                        description: "The AI model's response",
                    },
                    model_used: {
                        type: "string",
                        description: "Name/identifier of the AI model used",
                    },
                    response_time_ms: {
                        type: "number",
                        description: "Response time in milliseconds",
                    },
                    success: {
                        type: "boolean",
                        description: "Whether the query was successful",
                    },
                    error_details: {
                        type: "string",
                        description: "Error details if the query failed",
                    },
                    anonymous_id: {
                        type: "string",
                        description: "Anonymous identifier if user_id is not available",
                    },
                    timestamp: {
                        type: "string",
                        description: "ISO 8601 timestamp (defaults to current time)",
                    },
                    additional_properties: {
                        type: "object",
                        description: "Additional custom properties",
                    },
                },
                required: [
                    "user_id",
                    "conversation_id",
                    "query",
                    "model_used",
                    "success",
                ],
            },
        },
        {
            name: "track_ai_feedback",
            description: "Track user feedback and ratings for AI responses",
            inputSchema: {
                type: "object",
                properties: {
                    user_id: {
                        type: "string",
                        description: "The unique identifier for the user",
                    },
                    conversation_id: {
                        type: "string",
                        description: "Unique identifier for the conversation session",
                    },
                    message_id: {
                        type: "string",
                        description: "Unique identifier for the specific message being rated",
                    },
                    feedback_type: {
                        type: "string",
                        enum: ["thumbs_up", "thumbs_down", "rating"],
                        description: "Type of feedback provided",
                    },
                    feedback_value: {
                        type: "number",
                        minimum: 1,
                        maximum: 5,
                        description: "Numeric rating value (1-5, for rating type feedback)",
                    },
                    feedback_text: {
                        type: "string",
                        description: "Optional text feedback from the user",
                    },
                    anonymous_id: {
                        type: "string",
                        description: "Anonymous identifier if user_id is not available",
                    },
                    timestamp: {
                        type: "string",
                        description: "ISO 8601 timestamp (defaults to current time)",
                    },
                    additional_properties: {
                        type: "object",
                        description: "Additional custom properties",
                    },
                },
                required: ["user_id", "conversation_id", "message_id", "feedback_type"],
            },
        },
        {
            name: "track_custom_event",
            description: "Track a custom event with flexible properties",
            inputSchema: {
                type: "object",
                properties: {
                    user_id: {
                        type: "string",
                        description: "The unique identifier for the user",
                    },
                    anonymous_id: {
                        type: "string",
                        description: "Anonymous identifier (required if user_id not provided)",
                    },
                    event: {
                        type: "string",
                        description: "Name of the event to track",
                    },
                    properties: {
                        type: "object",
                        description: "Event properties as key-value pairs",
                    },
                    timestamp: {
                        type: "string",
                        description: "ISO 8601 timestamp (defaults to current time)",
                    },
                    context: {
                        type: "object",
                        description: "Additional context information",
                    },
                    integrations: {
                        type: "object",
                        description: "Integration-specific settings",
                    },
                },
                required: ["event"],
            },
        },
        {
            name: "identify_user",
            description: "Update user traits and profile information in Segment",
            inputSchema: {
                type: "object",
                properties: {
                    user_id: {
                        type: "string",
                        description: "The unique identifier for the user",
                    },
                    traits: {
                        type: "object",
                        description: "User traits to update",
                    },
                    anonymous_id: {
                        type: "string",
                        description: "Anonymous identifier to link with user_id",
                    },
                    timestamp: {
                        type: "string",
                        description: "ISO 8601 timestamp (defaults to current time)",
                    },
                    context: {
                        type: "object",
                        description: "Additional context information",
                    },
                    integrations: {
                        type: "object",
                        description: "Integration-specific settings",
                    },
                },
                required: ["user_id"],
            },
        },
    ];
}
function executeTrackingTool(toolName, params, trackingClient) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            switch (toolName) {
                case "track_ai_conversation": {
                    const validatedParams = tracking_schemas_js_1.TrackAIConversationSchema.parse(params);
                    const eventNameMap = {
                        conversation_started: "AI Conversation Started",
                        conversation_ended: "AI Conversation Ended",
                        message_sent: "AI Message Sent",
                        response_received: "AI Response Received",
                    };
                    const eventName = eventNameMap[validatedParams.event_type];
                    yield trackingClient.track({
                        userId: validatedParams.user_id,
                        anonymousId: validatedParams.anonymous_id,
                        event: eventName,
                        properties: Object.assign({ conversation_id: validatedParams.conversation_id }, validatedParams.properties),
                        timestamp: validatedParams.timestamp,
                    });
                    return {
                        success: true,
                        message: `Successfully tracked ${eventName} for conversation ${validatedParams.conversation_id}`,
                    };
                }
                case "track_ai_query": {
                    const validatedParams = tracking_schemas_js_1.TrackAIQuerySchema.parse(params);
                    yield trackingClient.track({
                        userId: validatedParams.user_id,
                        anonymousId: validatedParams.anonymous_id,
                        event: "AI Query Executed",
                        properties: Object.assign({ conversation_id: validatedParams.conversation_id, query: validatedParams.query, response: validatedParams.response, model_used: validatedParams.model_used, response_time_ms: validatedParams.response_time_ms, success: validatedParams.success, error_details: validatedParams.error_details }, validatedParams.additional_properties),
                        timestamp: validatedParams.timestamp,
                    });
                    return {
                        success: true,
                        message: `Successfully tracked AI query for conversation ${validatedParams.conversation_id}`,
                    };
                }
                case "track_ai_feedback": {
                    const validatedParams = tracking_schemas_js_1.TrackAIFeedbackSchema.parse(params);
                    yield trackingClient.trackAIFeedback(validatedParams.user_id, validatedParams.conversation_id, validatedParams.message_id, validatedParams.feedback_type, validatedParams.feedback_value, validatedParams.feedback_text, validatedParams.anonymous_id);
                    return {
                        success: true,
                        message: `Successfully tracked ${validatedParams.feedback_type} feedback for message ${validatedParams.message_id}`,
                    };
                }
                case "track_custom_event": {
                    const validatedParams = tracking_schemas_js_1.TrackEventSchema.parse(params);
                    yield trackingClient.track({
                        userId: validatedParams.user_id,
                        anonymousId: validatedParams.anonymous_id,
                        event: validatedParams.event,
                        properties: validatedParams.properties,
                        timestamp: validatedParams.timestamp,
                        context: validatedParams.context,
                        integrations: validatedParams.integrations,
                    });
                    return {
                        success: true,
                        message: `Successfully tracked custom event: ${validatedParams.event}`,
                    };
                }
                case "identify_user": {
                    const validatedParams = tracking_schemas_js_1.IdentifyEventSchema.parse(params);
                    yield trackingClient.identify({
                        userId: validatedParams.user_id,
                        anonymousId: validatedParams.anonymous_id,
                        traits: validatedParams.traits,
                        timestamp: validatedParams.timestamp,
                        context: validatedParams.context,
                        integrations: validatedParams.integrations,
                    });
                    return {
                        success: true,
                        message: `Successfully identified user: ${validatedParams.user_id}`,
                    };
                }
                default:
                    throw new Error(`Unknown tracking tool: ${toolName}`);
            }
        }
        catch (error) {
            return {
                success: false,
                error: error.message,
                tool: toolName,
            };
        }
    });
}
//# sourceMappingURL=tracking-tools.js.map