import { z } from "zod";
// Schema for tracking AI conversation events
export const TrackAIConversationSchema = z
    .object({
    user_id: z.string().min(1, "User ID is required"),
    conversation_id: z.string().min(1, "Conversation ID is required"),
    event_type: z.enum([
        "conversation_started",
        "conversation_ended",
        "message_sent",
        "response_received",
    ]),
    properties: z
        .object({
        model_name: z.string().optional(),
        input_tokens: z.number().min(0).optional(),
        output_tokens: z.number().min(0).optional(),
        response_time_ms: z.number().min(0).optional(),
        conversation_context: z.record(z.any()).optional(),
        success: z.boolean().optional(),
        error_details: z.string().optional(),
        message_content: z.string().optional(),
        response_content: z.string().optional(),
    })
        .optional()
        .default({}),
    anonymous_id: z.string().optional(),
    timestamp: z.string().optional(),
})
    .strict();
// Schema for tracking AI queries and responses
export const TrackAIQuerySchema = z
    .object({
    user_id: z.string().min(1, "User ID is required"),
    conversation_id: z.string().min(1, "Conversation ID is required"),
    query: z.string().min(1, "Query is required"),
    response: z.string().optional(),
    model_used: z.string().min(1, "Model name is required"),
    response_time_ms: z.number().min(0).optional(),
    success: z.boolean(),
    error_details: z.string().optional(),
    anonymous_id: z.string().optional(),
    timestamp: z.string().optional(),
    additional_properties: z.record(z.any()).optional(),
})
    .strict();
// Schema for tracking AI feedback events
export const TrackAIFeedbackSchema = z
    .object({
    user_id: z.string().min(1, "User ID is required"),
    conversation_id: z.string().min(1, "Conversation ID is required"),
    message_id: z.string().min(1, "Message ID is required"),
    feedback_type: z.enum(["thumbs_up", "thumbs_down", "rating"]),
    feedback_value: z.number().min(1).max(5).optional(),
    feedback_text: z.string().optional(),
    anonymous_id: z.string().optional(),
    timestamp: z.string().optional(),
    additional_properties: z.record(z.any()).optional(),
})
    .strict();
// Schema for general event tracking
export const TrackEventSchema = z
    .object({
    user_id: z.string().optional(),
    anonymous_id: z.string().optional(),
    event: z.string().min(1, "Event name is required"),
    properties: z.record(z.any()).optional(),
    timestamp: z.string().optional(),
    context: z.record(z.any()).optional(),
    integrations: z.record(z.any()).optional(),
})
    .refine((data) => data.user_id || data.anonymous_id, {
    message: "Either user_id or anonymous_id must be provided",
});
// Schema for identify events
export const IdentifyEventSchema = z
    .object({
    user_id: z.string().min(1, "User ID is required"),
    traits: z.record(z.any()).optional(),
    anonymous_id: z.string().optional(),
    timestamp: z.string().optional(),
    context: z.record(z.any()).optional(),
    integrations: z.record(z.any()).optional(),
})
    .strict();
//# sourceMappingURL=tracking-schemas.js.map