import express from "express";
import { randomUUID } from "node:crypto";
import { StreamableHTTPServerTransport } from "@modelcontextprotocol/sdk/server/streamableHttp.js";
import { createLogger } from "./logger.mjs";
export function createHttpTransportManager(server, config) {
    const logger = createLogger(config.logLevel);
    const app = express();
    // Map to store transports by session ID
    const transports = {};
    // Middleware
    app.use(express.json());
    app.use(express.urlencoded({ extended: true }));
    // CORS middleware
    app.use((req, res, next) => {
        res.header("Access-Control-Allow-Origin", "*");
        res.header("Access-Control-Allow-Methods", "GET, POST, OPTIONS, DELETE");
        res.header("Access-Control-Allow-Headers", "Content-Type, Authorization, Mcp-Session-Id");
        res.header("Access-Control-Expose-Headers", "Mcp-Session-Id");
        if (req.method === "OPTIONS") {
            res.status(200).end();
            return;
        }
        next();
    });
    // Helper function to create and connect a transport
    async function createAndConnectTransport(sessionId) {
        if (transports[sessionId]) {
            return transports[sessionId];
        }
        const transport = new StreamableHTTPServerTransport({
            enableJsonResponse: true,
            sessionIdGenerator: () => sessionId,
            onsessioninitialized: (actualId) => {
                logger.info(`Session initialized: ${actualId}`);
            },
        });
        // Manually assign session ID
        transport.sessionId = sessionId;
        // Set cleanup handler
        transport.onclose = () => {
            logger.info(`Transport closed for session: ${sessionId}`);
            if (transports[sessionId]) {
                delete transports[sessionId];
            }
        };
        // Store transport
        transports[sessionId] = transport;
        // Connect to MCP server
        try {
            await server.connect(transport);
            logger.info(`Transport connected for session: ${sessionId}`);
            return transport;
        }
        catch (error) {
            logger.error(`Failed to connect transport for session ${sessionId}:`, error);
            delete transports[sessionId];
            throw error;
        }
    }
    // Health check endpoint
    app.get("/health", (req, res) => {
        res.json({ status: "ok", timestamp: new Date().toISOString() });
    });
    // Main MCP endpoint for Streamable HTTP transport
    app.post("/mcp", async (req, res) => {
        const body = req.body;
        const rpcId = body && body.id !== undefined ? body.id : null;
        logger.info("Received MCP request", { method: body?.method, id: rpcId });
        try {
            // Extract session ID from header
            const clientSessionIdHeader = req.headers["mcp-session-id"];
            const actualClientSessionId = Array.isArray(clientSessionIdHeader)
                ? clientSessionIdHeader[0]
                : clientSessionIdHeader;
            let transport;
            let effectiveSessionId;
            // Check if this is an initialize request
            const isInitRequest = body && body.method === "initialize";
            if (isInitRequest) {
                // For initialize requests, create a new session
                effectiveSessionId = randomUUID();
                logger.info(`Creating new session for initialize request: ${effectiveSessionId}`);
                transport = await createAndConnectTransport(effectiveSessionId);
                // Set session ID in response header
                res.setHeader("Mcp-Session-Id", effectiveSessionId);
            }
            else if (actualClientSessionId && transports[actualClientSessionId]) {
                // For existing sessions, use the existing transport
                effectiveSessionId = actualClientSessionId;
                transport = transports[actualClientSessionId];
            }
            else {
                // Invalid session ID for non-initialize request
                logger.warn(`Invalid session ID for non-initialize request: ${actualClientSessionId}`);
                res.status(400).json({
                    jsonrpc: "2.0",
                    error: {
                        code: -32003,
                        message: "Bad Request: No valid session ID for non-initialize request.",
                    },
                    id: rpcId,
                });
                return;
            }
            // Set session ID in request headers for the transport
            req.headers["mcp-session-id"] = effectiveSessionId;
            // Always set session ID in response headers
            res.setHeader("Mcp-Session-Id", effectiveSessionId);
            // Handle the request using the transport
            await transport.handleRequest(req, res, body);
        }
        catch (error) {
            logger.error("Error handling MCP request:", error);
            if (!res.headersSent) {
                res.status(500).json({
                    jsonrpc: "2.0",
                    error: {
                        code: -32603,
                        message: "Internal server error during MCP request handling",
                    },
                    id: rpcId,
                });
            }
        }
    });
    // Handle GET requests for server-to-client notifications via SSE (optional)
    app.get("/mcp", async (req, res) => {
        const sessionId = req.headers["mcp-session-id"];
        if (!sessionId || !transports[sessionId]) {
            res.status(400).send("Invalid or missing session ID");
            return;
        }
        const transport = transports[sessionId];
        try {
            await transport.handleRequest(req, res);
        }
        catch (error) {
            logger.error("Error handling GET MCP request:", error);
            if (!res.headersSent) {
                res.status(500).send("Internal server error");
            }
        }
    });
    // Handle DELETE requests for session termination
    app.delete("/mcp", async (req, res) => {
        const sessionId = req.headers["mcp-session-id"];
        if (!sessionId) {
            res.status(400).json({ error: "Missing session ID" });
            return;
        }
        if (transports[sessionId]) {
            logger.info(`Terminating session: ${sessionId}`);
            const transport = transports[sessionId];
            transport.close();
            delete transports[sessionId];
            res.status(204).end();
        }
        else {
            res.status(404).json({ error: "Session not found" });
        }
    });
    let httpServer;
    return {
        app,
        async start() {
            return new Promise((resolve, reject) => {
                const port = config.httpPort || 3000;
                const host = config.httpHost || "0.0.0.0";
                httpServer = app.listen(port, host, () => {
                    logger.info(`MCP HTTP server listening on ${host}:${port}`);
                    logger.info(`MCP endpoint available at http://${host}:${port}/mcp`);
                    resolve();
                });
                httpServer.on("error", (error) => {
                    logger.error("HTTP server error:", error);
                    reject(error);
                });
            });
        },
        async stop() {
            return new Promise((resolve) => {
                if (httpServer) {
                    // Close all active transports
                    Object.values(transports).forEach((transport) => {
                        transport.close();
                    });
                    httpServer.close(() => {
                        logger.info("HTTP server stopped");
                        resolve();
                    });
                }
                else {
                    resolve();
                }
            });
        },
    };
}
//# sourceMappingURL=http-transport-simple.js.map